==> galois-0.3.1.tar.gz: galois-0.3.1/tests/polys/luts/irreducible_polys_3.py <==
"""
A module containing LUTs for irreducible polynomials over GF(3).

Sage:
    def integer(coeffs, order):
        i = 0
        for d, c in enumerate(coeffs[::-1]):
            i += (c.integer_representation() * order**d)
        return i

    order = 3
    degree =1
    list_ = []
    R = GF(order, repr="int")["x"]
    for f in R.polynomials(degree):
        if f.is_monic() and f.is_irreducible():
            list_.append(f.coefficients(sparse=False)[::-1])

    # Sort in lexicographically-increasing order
    if not is_prime(order):
        list_ = sorted(list_, key=lambda item: integer(item, order))

    print(f"IRREDUCIBLE_POLYS_{order}_{degree} = {list_}")
"""

# LUT items are poly coefficients in degree-descending order

IRREDUCIBLE_POLYS_3_1 = [
    [1, 0],
    [1, 1],
    [1, 2],
]

IRREDUCIBLE_POLYS_3_2 = [
    [1, 0, 1],
    [1, 1, 2],
    [1, 2, 2],
]

IRREDUCIBLE_POLYS_3_3 = [
    [1, 0, 2, 1],
    [1, 0, 2, 2],
    [1, 1, 0, 2],
    [1, 1, 1, 2],
    [1, 1, 2, 1],
    [1, 2, 0, 1],
    [1, 2, 1, 1],
    [1, 2, 2, 2],
]

IRREDUCIBLE_POLYS_3_4 = [
    [1, 0, 0, 1, 2],
    [1, 0, 0, 2, 2],
    [1, 0, 1, 0, 2],
    [1, 0, 1, 1, 1],
    [1, 0, 1, 2, 1],
    [1, 0, 2, 0, 2],
    [1, 1, 0, 0, 2],
    [1, 1, 0, 2, 1],
    [1, 1, 1, 0, 1],
    [1, 1, 1, 1, 1],
    [1, 1, 1, 2, 2],
    [1, 1, 2, 2, 2],
    [1, 2, 0, 0, 2],
    [1, 2, 0, 1, 1],
    [1, 2, 1, 0, 1],
    [1, 2, 1, 1, 2],
    [1, 2, 1, 2, 1],
    [1, 2, 2, 1, 2],
]

IRREDUCIBLE_POLYS_3_5 = [
    [1, 0, 0, 0, 2, 1],
    [1, 0, 0, 0, 2, 2],
    [1, 0, 0, 1, 1, 2],
    [1, 0, 0, 2, 1, 1],
    [1, 0, 1, 0, 1, 1],
    [1, 0, 1, 0, 1, 2],
    [1, 0, 1, 1, 0, 2],
    [1, 0, 1, 1, 2, 2],
    [1, 0, 1, 2, 0, 1],
    [1, 0, 1, 2, 2, 1],
    [1, 0, 2, 1, 0, 1],
    [1, 0, 2, 1, 1, 2],
    [1, 0, 2, 1, 2, 2],
    [1, 0, 2, 2, 0, 2],
    [1, 0, 2, 2, 1, 1],
    [1, 0, 2, 2, 2, 1],
    [1, 1, 0, 0, 0, 2],
    [1, 1, 0, 0, 1, 2],
    [1, 1, 0, 0, 2, 1],
    [1, 1, 0, 1, 0, 1],
    [1, 1, 0, 1, 1, 1],
    [1, 1, 0, 1, 2, 2],
    [1, 1, 1, 0, 1, 1],
    [1, 1, 1, 1, 2, 1],
    [1, 1, 1, 2, 1, 1],
    [1, 1, 1, 2, 1, 2],
    [1, 1, 2, 0, 0, 1],
    [1, 1, 2, 0, 2, 2],
    [1, 1, 2, 1, 0, 2],
    [1, 1, 2, 1, 1, 1],
    [1, 1, 2, 2, 0, 1],
    [1, 1, 2, 2, 0, 2],
    [1, 2, 0, 0, 0, 1],
    [1, 2, 0, 0, 1, 1],
    [1, 2, 0, 0, 2, 2],
    [1, 2, 0, 2, 0, 2],
    [1, 2, 0, 2, 1, 2],
    [1, 2, 0, 2, 2, 1],
    [1, 2, 1, 0, 1, 2],
    [1, 2, 1, 1, 1, 1],
    [1, 2, 1, 1, 1, 2],
    [1, 2, 1, 2, 2, 2],
    [1, 2, 2, 0, 0, 2],
    [1, 2, 2, 0, 2, 1],
    [1, 2, 2, 1, 0, 1],
    [1, 2, 2, 1, 0, 2],
    [1, 2, 2, 2, 0, 1],
    [1, 2, 2, 2, 1, 2],
]

IRREDUCIBLE_POLYS_3_6 = [
    [1, 0, 0, 0, 0, 1, 2],
    [1, 0, 0, 0, 0, 2, 2],
    [1, 0, 0, 0, 1, 1, 1],
    [1, 0, 0, 0, 1, 2, 1],
    [1, 0, 0, 0, 2, 0, 1],
    [1, 0, 0, 1, 0, 1, 2],
    [1, 0, 0, 1, 0, 2, 1],
    [1, 0, 0, 1, 1, 0, 1],
    [1, 0, 0, 1, 1, 2, 2],
    [1, 0, 0, 1, 2, 2, 1],
    [1, 0, 0, 2, 0, 1, 1],
    [1, 0, 0, 2, 0, 2, 2],
    [1, 0, 0, 2, 1, 0, 1],
    [1, 0, 0, 2, 1, 1, 2],
    [1, 0, 0, 2, 2, 1, 1],
    [1, 0, 1, 0, 2, 0, 1],
    [1, 0, 1, 0, 2, 1, 2],
    [1, 0, 1, 0, 2, 2, 2],
    [1, 0, 1, 1, 0, 0, 1],
    [1, 0, 1, 1, 0, 1, 1],
    [1, 0, 1, 1, 0, 2, 2],
    [1, 0, 1, 1, 1, 2, 2],
    [1, 0, 1, 2, 0, 0, 1],
    [1, 0, 1, 2, 0, 1, 2],
    [1, 0, 1, 2, 0, 2, 1],
    [1, 0, 1, 2, 1, 1, 2],
    [1, 0, 2, 0, 0, 0, 1],
    [1, 0, 2, 0, 1, 0, 1],
    [1, 0, 2, 0, 1, 1, 2],
    [1, 0, 2, 0, 1, 2, 2],
    [1, 0, 2, 1, 0, 2, 1],
    [1, 0, 2, 1, 1, 0, 2],
    [1, 0, 2, 1, 1, 1, 2],
    [1, 0, 2, 1, 1, 2, 1],
    [1, 0, 2, 2, 0, 1, 1],
    [1, 0, 2, 2, 1, 0, 2],
    [1, 0, 2, 2, 1, 1, 1],
    [1, 0, 2, 2, 1, 2, 2],
    [1, 1, 0, 0, 0, 0, 2],
    [1, 1, 0, 0, 0, 1, 2],
    [1, 1, 0, 0, 1, 1, 1],
    [1, 1, 0, 1, 0, 0, 2],
    [1, 1, 0, 1, 0, 1, 1],
    [1, 1, 0, 1, 1, 0, 1],
    [1, 1, 0, 1, 1, 1, 2],
    [1, 1, 0, 1, 2, 1, 2],
    [1, 1, 0, 2, 0, 0, 1],
    [1, 1, 0, 2, 1, 1, 1],
    [1, 1, 0, 2, 1, 2, 1],
    [1, 1, 0, 2, 2, 0, 1],
    [1, 1, 0, 2, 2, 0, 2],
    [1, 1, 1, 0, 0, 0, 1],
    [1, 1, 1, 0, 0, 1, 1],
    [1, 1, 1, 0, 1, 2, 2],
    [1, 1, 1, 0, 2, 0, 2],
    [1, 1, 1, 0, 2, 2, 1],
    [1, 1, 1, 1, 0, 1, 2],
    [1, 1, 1, 1, 0, 2, 1],
    [1, 1, 1, 1, 1, 1, 1],
    [1, 1, 1, 1, 1, 1, 2],
    [1, 1, 1, 1, 2, 2, 2],
    [1, 1, 1, 2, 0, 1, 1],
    [1, 1, 1, 2, 2, 0, 1],
    [1, 1, 1, 2, 2, 2, 2],
    [1, 1, 2, 0, 1, 0, 2],
    [1, 1, 2, 0, 1, 2, 1],
    [1, 1, 2, 0, 2, 2, 2],
    [1, 1, 2, 1, 0, 1, 2],
    [1, 1, 2, 1, 1, 0, 2],
    [1, 1, 2, 1, 1, 2, 2],
    [1, 1, 2, 1, 2, 1, 2],
    [1, 1, 2, 1, 2, 2, 1],
    [1, 1, 2, 2, 0, 0, 1],
    [1, 1, 2, 2, 0, 0, 2],
    [1, 1, 2, 2, 1, 2, 2],
    [1, 1, 2, 2, 2, 0, 2],
    [1, 1, 2, 2, 2, 2, 1],
    [1, 2, 0, 0, 0, 0, 2],
    [1, 2, 0, 0, 0, 2, 2],
    [1, 2, 0, 0, 1, 2, 1],
    [1, 2, 0, 1, 0, 0, 1],
    [1, 2, 0, 1, 1, 1, 1],
    [1, 2, 0, 1, 1, 2, 1],
    [1, 2, 0, 1, 2, 0, 1],
    [1, 2, 0, 1, 2, 0, 2],
    [1, 2, 0, 2, 0, 0, 2],
    [1, 2, 0, 2, 0, 2, 1],
    [1, 2, 0, 2, 1, 0, 1],
    [1, 2, 0, 2, 1, 2, 2],
    [1, 2, 0, 2, 2, 2, 2],
    [1, 2, 1, 0, 0, 0, 1],
    [1, 2, 1, 0, 0, 2, 1],
    [1, 2, 1, 0, 1, 1, 2],
    [1, 2, 1, 0, 2, 0, 2],
    [1, 2, 1, 0, 2, 1, 1],
    [1, 2, 1, 1, 0, 2, 1],
    [1, 2, 1, 1, 2, 0, 1],
    [1, 2, 1, 1, 2, 1, 2],
    [1, 2, 1, 2, 0, 1, 1],
    [1, 2, 1, 2, 0, 2, 2],
    [1, 2, 1, 2, 1, 2, 1],
    [1, 2, 1, 2, 1, 2, 2],
    [1, 2, 1, 2, 2, 1, 2],
    [1, 2, 2, 0, 1, 0, 2],
    [1, 2, 2, 0, 1, 1, 1],
    [1, 2, 2, 0, 2, 1, 2],
    [1, 2, 2, 1, 0, 0, 1],
    [1, 2, 2, 1, 0, 0, 2],
    [1, 2, 2, 1, 1, 1, 2],
    [1, 2, 2, 1, 2, 0, 2],
    [1, 2, 2, 1, 2, 1, 1],
    [1, 2, 2, 2, 0, 2, 2],
    [1, 2, 2, 2, 1, 0, 2],
    [1, 2, 2, 2, 1, 1, 2],
    [1, 2, 2, 2, 2, 1, 1],
    [1, 2, 2, 2, 2, 2, 2],
]

==> galois-0.3.4.tar.gz: galois-0.3.4/tests/polys/luts/irreducible_polys_3.py <==
"""
A module containing LUTs for irreducible polynomials over GF(3).

Sage:
    def integer(coeffs, order):
        i = 0
        for d, c in enumerate(coeffs[::-1]):
            i += (c.integer_representation() * order**d)
        return i

    order = 3
    degree =1
    list_ = []
    R = GF(order, repr="int")["x"]
    for f in R.polynomials(degree):
        if f.is_monic() and f.is_irreducible():
            list_.append(f.coefficients(sparse=False)[::-1])

    # Sort in lexicographical order
    if not is_prime(order):
        list_ = sorted(list_, key=lambda item: integer(item, order))

    print(f"IRREDUCIBLE_POLYS_{order}_{degree} = {list_}")
"""

# LUT items are poly coefficients in degree-descending order

IRREDUCIBLE_POLYS_3_1 = [
    [1, 0],
    [1, 1],
    [1, 2],
]

IRREDUCIBLE_POLYS_3_2 = [
    [1, 0, 1],
    [1, 1, 2],
    [1, 2, 2],
]

IRREDUCIBLE_POLYS_3_3 = [
    [1, 0, 2, 1],
    [1, 0, 2, 2],
    [1, 1, 0, 2],
    [1, 1, 1, 2],
    [1, 1, 2, 1],
    [1, 2, 0, 1],
    [1, 2, 1, 1],
    [1, 2, 2, 2],
]

IRREDUCIBLE_POLYS_3_4 = [
    [1, 0, 0, 1, 2],
    [1, 0, 0, 2, 2],
    [1, 0, 1, 0, 2],
    [1, 0, 1, 1, 1],
    [1, 0, 1, 2, 1],
    [1, 0, 2, 0, 2],
    [1, 1, 0, 0, 2],
    [1, 1, 0, 2, 1],
    [1, 1, 1, 0, 1],
    [1, 1, 1, 1, 1],
    [1, 1, 1, 2, 2],
    [1, 1, 2, 2, 2],
    [1, 2, 0, 0, 2],
    [1, 2, 0, 1, 1],
    [1, 2, 1, 0, 1],
    [1, 2, 1, 1, 2],
    [1, 2, 1, 2, 1],
    [1, 2, 2, 1, 2],
]

IRREDUCIBLE_POLYS_3_5 = [
    [1, 0, 0, 0, 2, 1],
    [1, 0, 0, 0, 2, 2],
    [1, 0, 0, 1, 1, 2],
    [1, 0, 0, 2, 1, 1],
    [1, 0, 1, 0, 1, 1],
    [1, 0, 1, 0, 1, 2],
    [1, 0, 1, 1, 0, 2],
    [1, 0, 1, 1, 2, 2],
    [1, 0, 1, 2, 0, 1],
    [1, 0, 1, 2, 2, 1],
    [1, 0, 2, 1, 0, 1],
    [1, 0, 2, 1, 1, 2],
    [1, 0, 2, 1, 2, 2],
    [1, 0, 2, 2, 0, 2],
    [1, 0, 2, 2, 1, 1],
    [1, 0, 2, 2, 2, 1],
    [1, 1, 0, 0, 0, 2],
    [1, 1, 0, 0, 1, 2],
    [1, 1, 0, 0, 2, 1],
    [1, 1, 0, 1, 0, 1],
    [1, 1, 0, 1, 1, 1],
    [1, 1, 0, 1, 2, 2],
    [1, 1, 1, 0, 1, 1],
    [1, 1, 1, 1, 2, 1],
    [1, 1, 1, 2, 1, 1],
    [1, 1, 1, 2, 1, 2],
    [1, 1, 2, 0, 0, 1],
    [1, 1, 2, 0, 2, 2],
    [1, 1, 2, 1, 0, 2],
    [1, 1, 2, 1, 1, 1],
    [1, 1, 2, 2, 0, 1],
    [1, 1, 2, 2, 0, 2],
    [1, 2, 0, 0, 0, 1],
    [1, 2, 0, 0, 1, 1],
    [1, 2, 0, 0, 2, 2],
    [1, 2, 0, 2, 0, 2],
    [1, 2, 0, 2, 1, 2],
    [1, 2, 0, 2, 2, 1],
    [1, 2, 1, 0, 1, 2],
    [1, 2, 1, 1, 1, 1],
    [1, 2, 1, 1, 1, 2],
    [1, 2, 1, 2, 2, 2],
    [1, 2, 2, 0, 0, 2],
    [1, 2, 2, 0, 2, 1],
    [1, 2, 2, 1, 0, 1],
    [1, 2, 2, 1, 0, 2],
    [1, 2, 2, 2, 0, 1],
    [1, 2, 2, 2, 1, 2],
]

IRREDUCIBLE_POLYS_3_6 = [
    [1, 0, 0, 0, 0, 1, 2],
    [1, 0, 0, 0, 0, 2, 2],
    [1, 0, 0, 0, 1, 1, 1],
    [1, 0, 0, 0, 1, 2, 1],
    [1, 0, 0, 0, 2, 0, 1],
    [1, 0, 0, 1, 0, 1, 2],
    [1, 0, 0, 1, 0, 2, 1],
    [1, 0, 0, 1, 1, 0, 1],
    [1, 0, 0, 1, 1, 2, 2],
    [1, 0, 0, 1, 2, 2, 1],
    [1, 0, 0, 2, 0, 1, 1],
    [1, 0, 0, 2, 0, 2, 2],
    [1, 0, 0, 2, 1, 0, 1],
    [1, 0, 0, 2, 1, 1, 2],
    [1, 0, 0, 2, 2, 1, 1],
    [1, 0, 1, 0, 2, 0, 1],
    [1, 0, 1, 0, 2, 1, 2],
    [1, 0, 1, 0, 2, 2, 2],
    [1, 0, 1, 1, 0, 0, 1],
    [1, 0, 1, 1, 0, 1, 1],
    [1, 0, 1, 1, 0, 2, 2],
    [1, 0, 1, 1, 1, 2, 2],
    [1, 0, 1, 2, 0, 0, 1],
    [1, 0, 1, 2, 0, 1, 2],
    [1, 0, 1, 2, 0, 2, 1],
    [1, 0, 1, 2, 1, 1, 2],
    [1, 0, 2, 0, 0, 0, 1],
    [1, 0, 2, 0, 1, 0, 1],
    [1, 0, 2, 0, 1, 1, 2],
    [1, 0, 2, 0, 1, 2, 2],
    [1, 0, 2, 1, 0, 2, 1],
    [1, 0, 2, 1, 1, 0, 2],
    [1, 0, 2, 1, 1, 1, 2],
    [1, 0, 2, 1, 1, 2, 1],
    [1, 0, 2, 2, 0, 1, 1],
    [1, 0, 2, 2, 1, 0, 2],
    [1, 0, 2, 2, 1, 1, 1],
    [1, 0, 2, 2, 1, 2, 2],
    [1, 1, 0, 0, 0, 0, 2],
    [1, 1, 0, 0, 0, 1, 2],
    [1, 1, 0, 0, 1, 1, 1],
    [1, 1, 0, 1, 0, 0, 2],
    [1, 1, 0, 1, 0, 1, 1],
    [1, 1, 0, 1, 1, 0, 1],
    [1, 1, 0, 1, 1, 1, 2],
    [1, 1, 0, 1, 2, 1, 2],
    [1, 1, 0, 2, 0, 0, 1],
    [1, 1, 0, 2, 1, 1, 1],
    [1, 1, 0, 2, 1, 2, 1],
    [1, 1, 0, 2, 2, 0, 1],
    [1, 1, 0, 2, 2, 0, 2],
    [1, 1, 1, 0, 0, 0, 1],
    [1, 1, 1, 0, 0, 1, 1],
    [1, 1, 1, 0, 1, 2, 2],
    [1, 1, 1, 0, 2, 0, 2],
    [1, 1, 1, 0, 2, 2, 1],
    [1, 1, 1, 1, 0, 1, 2],
    [1, 1, 1, 1, 0, 2, 1],
    [1, 1, 1, 1, 1, 1, 1],
    [1, 1, 1, 1, 1, 1, 2],
    [1, 1, 1, 1, 2, 2, 2],
    [1, 1, 1, 2, 0, 1, 1],
    [1, 1, 1, 2, 2, 0, 1],
    [1, 1, 1, 2, 2, 2, 2],
    [1, 1, 2, 0, 1, 0, 2],
    [1, 1, 2, 0, 1, 2, 1],
    [1, 1, 2, 0, 2, 2, 2],
    [1, 1, 2, 1, 0, 1, 2],
    [1, 1, 2, 1, 1, 0, 2],
    [1, 1, 2, 1, 1, 2, 2],
    [1, 1, 2, 1, 2, 1, 2],
    [1, 1, 2, 1, 2, 2, 1],
    [1, 1, 2, 2, 0, 0, 1],
    [1, 1, 2, 2, 0, 0, 2],
    [1, 1, 2, 2, 1, 2, 2],
    [1, 1, 2, 2, 2, 0, 2],
    [1, 1, 2, 2, 2, 2, 1],
    [1, 2, 0, 0, 0, 0, 2],
    [1, 2, 0, 0, 0, 2, 2],
    [1, 2, 0, 0, 1, 2, 1],
    [1, 2, 0, 1, 0, 0, 1],
    [1, 2, 0, 1, 1, 1, 1],
    [1, 2, 0, 1, 1, 2, 1],
    [1, 2, 0, 1, 2, 0, 1],
    [1, 2, 0, 1, 2, 0, 2],
    [1, 2, 0, 2, 0, 0, 2],
    [1, 2, 0, 2, 0, 2, 1],
    [1, 2, 0, 2, 1, 0, 1],
    [1, 2, 0, 2, 1, 2, 2],
    [1, 2, 0, 2, 2, 2, 2],
    [1, 2, 1, 0, 0, 0, 1],
    [1, 2, 1, 0, 0, 2, 1],
    [1, 2, 1, 0, 1, 1, 2],
    [1, 2, 1, 0, 2, 0, 2],
    [1, 2, 1, 0, 2, 1, 1],
    [1, 2, 1, 1, 0, 2, 1],
    [1, 2, 1, 1, 2, 0, 1],
    [1, 2, 1, 1, 2, 1, 2],
    [1, 2, 1, 2, 0, 1, 1],
    [1, 2, 1, 2, 0, 2, 2],
    [1, 2, 1, 2, 1, 2, 1],
    [1, 2, 1, 2, 1, 2, 2],
    [1, 2, 1, 2, 2, 1, 2],
    [1, 2, 2, 0, 1, 0, 2],
    [1, 2, 2, 0, 1, 1, 1],
    [1, 2, 2, 0, 2, 1, 2],
    [1, 2, 2, 1, 0, 0, 1],
    [1, 2, 2, 1, 0, 0, 2],
    [1, 2, 2, 1, 1, 1, 2],
    [1, 2, 2, 1, 2, 0, 2],
    [1, 2, 2, 1, 2, 1, 1],
    [1, 2, 2, 2, 0, 2, 2],
    [1, 2, 2, 2, 1, 0, 2],
    [1, 2, 2, 2, 1, 1, 2],
    [1, 2, 2, 2, 2, 1, 1],
    [1, 2, 2, 2, 2, 2, 2],
]
